# -*- coding: utf-8 -*-

###############################################################################
#
# GetIncident
# Returns detailed information about a specified incident.
#
# Python versions 2.6, 2.7, 3.x
#
# Copyright 2014, Temboo Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
# either express or implied. See the License for the specific
# language governing permissions and limitations under the License.
#
#
###############################################################################

from temboo.core.choreography import Choreography
from temboo.core.choreography import InputSet
from temboo.core.choreography import ResultSet
from temboo.core.choreography import ChoreographyExecution

import json

class GetIncident(Choreography):

    def __init__(self, temboo_session):
        """
        Create a new instance of the GetIncident Choreo. A TembooSession object, containing a valid
        set of Temboo credentials, must be supplied.
        """
        super(GetIncident, self).__init__(temboo_session, '/Library/PagerDuty/Incidents/GetIncident')


    def new_input_set(self):
        return GetIncidentInputSet()

    def _make_result_set(self, result, path):
        return GetIncidentResultSet(result, path)

    def _make_execution(self, session, exec_id, path):
        return GetIncidentChoreographyExecution(session, exec_id, path)

class GetIncidentInputSet(InputSet):
    """
    An InputSet with methods appropriate for specifying the inputs to the GetIncident
    Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    """
    def set_APIKey(self, value):
        """
        Set the value of the APIKey input for this Choreo. ((required, string) The API Key provided by PagerDuty.)
        """
        super(GetIncidentInputSet, self)._set_input('APIKey', value)
    def set_IncidentID(self, value):
        """
        Set the value of the IncidentID input for this Choreo. ((required, string) An incident ID, or an incident number.)
        """
        super(GetIncidentInputSet, self)._set_input('IncidentID', value)
    def set_SubDomain(self, value):
        """
        Set the value of the SubDomain input for this Choreo. ((required, string) The subdomain of your PagerDuty site address.)
        """
        super(GetIncidentInputSet, self)._set_input('SubDomain', value)

class GetIncidentResultSet(ResultSet):
    """
    A ResultSet with methods tailored to the values returned by the GetIncident Choreo.
    The ResultSet object is used to retrieve the results of a Choreo execution.
    """

    def getJSONFromString(self, str):
        return json.loads(str)

    def get_Response(self):
        """
        Retrieve the value for the "Response" output from this Choreo execution. ((json) The response from PagerDuty.)
        """
        return self._output.get('Response', None)

class GetIncidentChoreographyExecution(ChoreographyExecution):

    def _make_result_set(self, response, path):
        return GetIncidentResultSet(response, path)
